pub struct JsonStore { /* private fields */ }Expand description
Mutable JSON-backed key-value store with typed helper accessors.
Implementations
Sourceimpl JsonStore
impl JsonStore
Sourcepub fn get_string(&self, key: &str) -> Option<&str>
pub fn get_string(&self, key: &str) -> Option<&str>
Returns a string value for key when present and correctly typed.
Sourcepub fn set_string(&mut self, key: &str, value: impl Into<String>)
pub fn set_string(&mut self, key: &str, value: impl Into<String>)
Sets a string value for key.
Sourcepub fn get_i64(&self, key: &str) -> Option<i64>
pub fn get_i64(&self, key: &str) -> Option<i64>
Returns an integer value for key when present and correctly typed.
Sourcepub fn get_bool(&self, key: &str) -> Option<bool>
pub fn get_bool(&self, key: &str) -> Option<bool>
Returns a boolean value for key when present and correctly typed.
Sourcepub fn accessors_are_unique(config: &StoreAccessorConfig) -> bool
pub fn accessors_are_unique(config: &StoreAccessorConfig) -> bool
Returns true when every accessor name is unique.