Module touch

Module touch 

Touch helpers.

Traits

TouchRecord
Trait implemented by records that support touch-style timestamp updates.
TouchTarget
A dynamically dispatched target that can be touched.

Functions

cascade_touch
Touches the record and then cascades the same timestamp update to associations.
touch
Updates the updated_at timestamp to the current time.
touch_field
Updates a specific timestamp column to the current time.